==> plasma-nm-5.3.95.tar.xz: plasma-nm-5.3.95/vpn/openswan/openswanauth.h <==
/*
    Copyright 2013 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_NM_OPENSWAN_AUTH_H
#define PLASMA_NM_OPENSWAN_AUTH_H

#include <NetworkManagerQt/VpnSetting>

#include "settingwidget.h"

class OpenswanAuthDialogPrivate;

class OpenswanAuthDialog : public SettingWidget
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(OpenswanAuthDialog)
public:
    explicit OpenswanAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, QWidget * parent = 0);
    ~OpenswanAuthDialog();
    virtual void readSecrets();
    virtual QVariantMap setting(bool agentOwned = false) const;

private Q_SLOTS:
    void showPasswordsChanged(bool);

private:
    OpenswanAuthDialogPrivate * const d_ptr;
};

#endif // PLASMA_NM_OPENSWAN_AUTH_H

==> plasma-nm_5.12.8.orig.tar.xz: plasma-nm-5.12.8/vpn/openswan/openswanauth.h <==
/*
    Copyright 2013 Jan Grulich <jgrulich@redhat.com>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef PLASMA_NM_OPENSWAN_AUTH_H
#define PLASMA_NM_OPENSWAN_AUTH_H

#include <NetworkManagerQt/VpnSetting>

#include "settingwidget.h"

class OpenswanAuthDialogPrivate;

class OpenswanAuthDialog : public SettingWidget
{
    Q_OBJECT
    Q_DECLARE_PRIVATE(OpenswanAuthDialog)
public:
    explicit OpenswanAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
    ~OpenswanAuthDialog();
    virtual void readSecrets();
    virtual QVariantMap setting() const;

private:
    OpenswanAuthDialogPrivate *const d_ptr;
};

#endif // PLASMA_NM_OPENSWAN_AUTH_H
